import requests

class ConnectorLog:
    def __init__(self, base_url, token):
        self.base_url = base_url
        self.token = token

    def create_connector_log(self, connector_name, start_time):
        response = requests.post(
            f"{self.base_url}/logConnector",
            json={
                'connectorName': connector_name,
                'startTime': start_time
            },
            headers={
                'Authorization': f'Bearer {self.token}'
            }
        )
        response.raise_for_status()  # Raise an exception for HTTP errors
        return response.json()

    def update_connector_log(self, connector_log_id, end_time):
        url = f"{self.base_url}/logConnector/end"
        headers = {
            'Authorization': f'Bearer {self.token}'
        }
        data = {
            'connectorLogId': connector_log_id,
            'endTime': end_time
        }
        response = requests.post(url, json=data, headers=headers)
        response.raise_for_status()  # Raise an error for bad responses (4xx or 5xx)
        
        # Since the response is plain text, return the text content
        return response.text




import requests

class EndpointDetails:
    def __init__(self, base_url, token):
        self.base_url = base_url
        self.token = token

    def create_endpoint_detail(self, connector_log_id, endpoint_name, endpoint_started_at, endpoint_ended_at, records_count, record_max_date):
        url = f"{self.base_url}/logEndpoint"
        headers = {
            'Authorization': f'Bearer {self.token}'
        }
        data = {
            'connectorLogId': connector_log_id,
            'endpointName': endpoint_name,
            'endpointStartedAt': endpoint_started_at,
            'endpointEndedAt': endpoint_ended_at,
            'recordsCount': records_count,
            'recordMaxDate': record_max_date
        }
        response = requests.post(url, json=data, headers=headers)
        response.raise_for_status()  # Raise an error for bad responses (4xx or 5xx)
        return response.json()




import requests

class Auth:
    def __init__(self, base_url):
        self.base_url = base_url

    def login(self, username, password):
        response = requests.post(
            f"{self.base_url}/auth",
            json={
                'username': username,
                'password': password
            }
        )
        response.raise_for_status()  # Raise an exception for HTTP errors
        return response.json().get('token')

# Example usage:
# auth = Auth('https://bv.dataanalytics.nl:3000')
# token = auth.login('admin', 'admin@123')
# print(token)



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='bvlogger',
    version='1.0.4',
    author='Your Name',
    author_email='your.email@example.com',
    description='A brief description of your project',
    long_description=long_description,
    long_description_content_type='text/markdown', 
    url='https://github.com/yourusername/bvlogger',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)